@@ -139,8 +139,8 @@ append_word (GPtrArray **word_array,
     }
 }
 
-static GPtrArray *
-strip_utf8_string (const gchar *string)
+GPtrArray *
+empathy_live_search_strip_utf8_string (const gchar *string)
 {
   GPtrArray *word_array = NULL;
   GString *word = NULL;
@@ -230,8 +230,8 @@ live_search_match_prefix (const gchar *string,
   return FALSE;
 }
 
-static gboolean
-live_search_match_words (const gchar *string,
+gboolean
+empathy_live_search_match_words (const gchar *string,
     GPtrArray *words)
 {
   guint i;
@@ -246,13 +246,22 @@ live_search_match_words (const gchar *string,
   return TRUE;
 }
 
+static gboolean
+fire_key_navigation_sig (EmpathyLiveSearch *self,
+    GdkEventKey *event)
+{
+  gboolean ret;
+
+  g_signal_emit (self, signals[KEYNAV], 0, event, &ret);
+  return ret;
+}
+
 static gboolean
 live_search_entry_key_pressed_cb (GtkEntry *entry,
     GdkEventKey *event,
     gpointer user_data)
 {
   EmpathyLiveSearch *self = EMPATHY_LIVE_SEARCH (user_data);
-  gboolean ret;
 
   /* if esc key pressed, hide the search */
   if (event->keyval == GDK_KEY_Escape)
@@ -263,12 +272,22 @@ live_search_entry_key_pressed_cb (GtkEntry *entry,
 
   /* emit key navigation signal, so other widgets can respond to it properly */
   if (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_Down
-      || event->keyval == GDK_KEY_Left || event->keyval == GDK_KEY_Right)
+      || event->keyval == GDK_KEY_Page_Up || event->keyval == GDK_KEY_Page_Down)
      {
-       g_signal_emit (self, signals[KEYNAV], 0, event, &ret);
-       return ret;
+       return fire_key_navigation_sig (self, event);
      }
 
+  if (event->keyval == GDK_KEY_Home || event->keyval == GDK_KEY_End ||
+      event->keyval == GDK_KEY_space)
+    {
+      /* If the live search is visible, the entry should catch the Home/End
+       * and space events */
+      if (!gtk_widget_get_visible (GTK_WIDGET (self)))
+        {
+          return fire_key_navigation_sig (self, event);
+        }
+    }
+
   return FALSE;
 }
 
@@ -290,7 +309,7 @@ live_search_text_changed (GtkEntry *entry,
   if (priv->stripped_words != NULL)
     g_ptr_array_unref (priv->stripped_words);
 
-  priv->stripped_words = strip_utf8_string (text);
+  priv->stripped_words = empathy_live_search_strip_utf8_string (text);
 
   g_object_notify (G_OBJECT (self), "text");
 }
@@ -330,11 +349,22 @@ live_search_key_press_event_cb (GtkWidget *widget,
       event->keyval == GDK_KEY_Control_R)
     return FALSE;
 
-  /* dont forward the up and down arrow keys to the entry, they are needed for
-   * navigation in the treeview and are not needed in the search entry */
-   if (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_Down)
+  /* dont forward the up/down and Page Up/Down arrow keys to the entry,
+   * they are needed for navigation in the treeview and are not needed in
+   * the search entry */
+   if (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_Down ||
+       event->keyval == GDK_KEY_Page_Up || event->keyval == GDK_KEY_Page_Down)
      return FALSE;
 
+   if (event->keyval == GDK_KEY_Home || event->keyval == GDK_KEY_End ||
+       event->keyval == GDK_KEY_space)
+     {
+       /* Home/End and space keys have to be forwarded to the entry only if
+        * the live search is visible (to move the cursor inside the entry). */
+       if (!gtk_widget_get_visible (GTK_WIDGET (self)))
+         return FALSE;
+     }
+
   /* realize the widget if it is not realized yet */
   gtk_widget_realize (priv->search_entry);
   if (!gtk_widget_has_focus (priv->search_entry))
@@ -454,12 +484,17 @@ live_search_set_property (GObject *object,
 }
 
 static void
-live_search_hide (GtkWidget *widget)
+live_search_unmap (GtkWidget *widget)
 {
   EmpathyLiveSearch *self = EMPATHY_LIVE_SEARCH (widget);
   EmpathyLiveSearchPriv *priv = GET_PRIV (self);
 
-  GTK_WIDGET_CLASS (empathy_live_search_parent_class)->hide (widget);
+  GTK_WIDGET_CLASS (empathy_live_search_parent_class)->unmap (widget);
+
+  /* unmap can happen if a parent gets hidden, in that case we want to hide
+   * the live search as well, so when it gets mapped again, the live search
+   * won't be shown. */
+  gtk_widget_hide (widget);
 
   gtk_entry_set_text (GTK_ENTRY (priv->search_entry), "");
   gtk_widget_grab_focus (priv->hook_widget);
@@ -502,7 +537,7 @@ empathy_live_search_class_init (EmpathyLiveSearchClass *klass)
   object_class->get_property = live_search_get_property;
   object_class->set_property = live_search_set_property;
 
-  widget_class->hide = live_search_hide;
+  widget_class->unmap = live_search_unmap;
   widget_class->show = live_search_show;
   widget_class->grab_focus = live_search_grab_focus;
 
@@ -667,7 +702,7 @@ empathy_live_search_match (EmpathyLiveSearch *self,
 
   priv = GET_PRIV (self);
 
-  return live_search_match_words (string, priv->stripped_words);
+  return empathy_live_search_match_words (string, priv->stripped_words);
 }
 
 gboolean
@@ -677,11 +712,18 @@ empathy_live_search_match_string (const gchar *string,
   GPtrArray *words;
   gboolean match;
 
-  words = strip_utf8_string (prefix);
-  match = live_search_match_words (string, words);
+  words = empathy_live_search_strip_utf8_string (prefix);
+  match = empathy_live_search_match_words (string, words);
   if (words != NULL)
     g_ptr_array_unref (words);
 
   return match;
 }
 
+GPtrArray *
+empathy_live_search_get_words (EmpathyLiveSearch *self)
+{
+  EmpathyLiveSearchPriv *priv = GET_PRIV (self);
+
+  return priv->stripped_words;
+}
