@@ -1984,9 +1984,11 @@ main_window_connection_items_setup (EmpathyMainWindow *window,
 		"room_join_favorites",
 		"chat_new_message",
 		"chat_new_call",
+		"chat_search_contacts",
 		"chat_add_contact",
 		"edit_personal_information",
-		"edit_blocked_contacts"
+		"edit_blocked_contacts",
+		"edit_search_contacts"
 	};
 
 	for (i = 0, list = NULL; i < G_N_ELEMENTS (actions_connected); i++) {
@@ -2008,7 +2010,7 @@ account_manager_prepared_cb (GObject      *source_object,
 	EmpathyMainWindowPriv *priv = GET_PRIV (window);
 	GError *error = NULL;
 
-	if (!tp_account_manager_prepare_finish (manager, result, &error)) {
+	if (!tp_proxy_prepare_finish (manager, result, &error)) {
 		DEBUG ("Failed to prepare account manager: %s", error->message);
 		g_error_free (error);
 		return;
@@ -2206,7 +2208,7 @@ empathy_main_window_init (EmpathyMainWindow *window)
 
 	priv->account_manager = tp_account_manager_dup ();
 
-	tp_account_manager_prepare_async (priv->account_manager, NULL,
+	tp_proxy_prepare_async (priv->account_manager, NULL,
 					  account_manager_prepared_cb, window);
 
 	priv->errors = g_hash_table_new_full (g_direct_hash,
